from setuptools import setup

setup(name = 'upload_dnatools_36',
version = '0.1',
description = 'textbook example',
url = 'http://example.com',
author = 'Example',
author_email = 'Example@gmail.com',
license = 'Example',
packages = ['package_1'])
